package com.casic.missiles.modular.alarm.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.casic.missiles.core.datascope.DataScope;
import com.casic.missiles.model.response.ResponseData;
import com.casic.missiles.modular.alarm.model.AlarmLevelParam;
import com.casic.missiles.modular.system.model.AlarmLevel;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 服务类
 * </p>
 *
 * @author 123
 * @since 2019-10-15
 */
public interface IAlarmLevelService extends IService<AlarmLevel> {

    List<Map<String, Object>> getLevelList(Long tenantId,Long  deviceType);

    List<AlarmLevel> selectByNameAndTenList(Long tenantId, String name);

    AlarmLevel selectByNameAndTenAndLevel(Long tenantId, String name, Integer level);

    AlarmLevel selectByID(Long id);

    ResponseData deleteByCondition(String deviceType, String name, String tenantId);

    ResponseData addAlarmLevel(AlarmLevelParam alarmLevel);

    ResponseData updateAlarmLevel(AlarmLevelParam alarmLevelParam);
}
